import React, { useState, useEffect } from 'react';
import { Redirect, Route, Switch, useHistory, useRouteMatch, match as MatchType, Link as RouterLink } from 'react-router-dom';
import ContentAccessor, { Content } from '../accessor/contents';
import { LoadingCircle } from '../component/loading';
import { Link, Paper, makeStyles, Theme, Box, useTheme, Typography } from '@material-ui/core';
import { ThumbnailContainer } from '../page/reader/reader';
import { TagChip } from '../component/tagchip';
import { MangaReader } from '../page/reader/manga';

export const makeContentInfoUrl = (id: number) => `/doc/${id}`;
export const makeContentReaderUrl = (id: number) => `/doc/${id}/reader`;

const useStyles = makeStyles((theme: Theme) => ({
    root: {
        display: "flex",
        [theme.breakpoints.down("sm")]: {
            flexDirection: "column",
            alignItems: "center",
        }
    },
    thumbnail_content: {
        maxHeight: '400px',
        maxWidth: 'min(400px, 100vw)',
    },
    tag_list: {
        display: 'flex',
        justifyContent: 'flex-start',
        flexWrap: 'wrap',
        overflowY: 'hidden',
        '& > *': {
            margin: theme.spacing(0.5),
        },
    },
    title: {
        marginLeft: theme.spacing(1),
    },
    InfoContainer: {
        display: 'grid',
        gridTemplateColumns: '100px auto',
        overflowY: 'hidden',
    }
}))

export const ContentInfo = (props: { content: Content, children?: React.ReactNode }) => {
    const classes = useStyles();
    const theme = useTheme();
    const content = props?.content;
    let allTag = content.tags;
    const artists = allTag.filter(x => x.startsWith("artist:")).map(x => x.substr(7));
    allTag = allTag.filter(x => !x.startsWith("artist:"));
    return (<Paper className={classes.root}>
        <Link component={RouterLink} to={makeContentReaderUrl(content.id)}>
            <ThumbnailContainer content={content} className={classes.thumbnail_content}></ThumbnailContainer>
        </Link>
        <Box style={{ padding: theme.spacing(1) }}>
            <Link variant='h5' color='inherit' component={RouterLink} to={makeContentReaderUrl(content.id)}
                className={classes.title}>
                {content.title}
            </Link>
            <Box className={classes.InfoContainer}>
                <Typography variant='subtitle1'>Artist</Typography>
                <Box style={{alignSelf:"center"}}>{artists.join(", ")}</Box>
                <Typography variant='subtitle1'>Tags</Typography>
                <Box className={classes.tag_list}>
                    {allTag.map(x => {
                        return (<TagChip key={x} label={x} clickable={true} tagname={x} size="small"></TagChip>);
                    })}
                </Box>
            </Box>
        </Box>
    </Paper>);
}