import React, { useState, useEffect } from 'react';
import { Redirect, Route, Switch, useHistory, useRouteMatch, match as MatchType, Link as RouterLink } from 'react-router-dom';
import ContentAccessor, { Content } from '../accessor/contents';
import { LoadingCircle } from '../component/loading';
import { Link, Paper, makeStyles, Theme, Box, useTheme, Typography } from '@material-ui/core';
import { MangaReader } from './reader/manga';
import { ContentInfo } from '../component/mod';

export const makeContentInfoUrl = (id: number) => `/doc/${id}`;
export const makeMangaReaderUrl = (id: number) => `/doc/${id}/reader`;

type ContentState = {
    content: Content | undefined,
    notfound: boolean,
}

export const ContentAbout = (prop: { match: MatchType }) => {
    const match = useRouteMatch("/doc/:id");
    if (match == null) {
        throw new Error("unreachable");
    }
    const m = /\/doc\/(\d+)/.exec(match.url);
    const id = m !== null ? Number.parseInt(m[1]) : NaN;
    const [info, setInfo] = useState<ContentState>({ content: undefined, notfound:false });
    useEffect(() => {
        (async () => {
            if (!isNaN(id)) {
                const c = await ContentAccessor.findById(id);
                setInfo({ content: c, notfound: c === undefined });
            }
        })()
    }, []);
    if (isNaN(id)) {
        return (<Typography variant='h2'>Oops. Invalid ID</Typography>)
    }
    else if(info.notfound){
        return (<Typography variant='h2'>Content has been removed.</Typography>)
    }
    else if (info.content === undefined) {
        return (<LoadingCircle />);
    }
    else return (<Switch>
        <Route exact path={`${prop.match.path}/:id`}>
            <ContentInfo content={info.content}></ContentInfo>
        </Route>
        <Route exact path={`${prop.match.path}/:id/reader`}>
            <MangaReader content={info.content}></MangaReader>
        </Route>
        <Route>
            <div>404 Not Found invalid url : {prop.match.path}</div>
        </Route>
    </Switch>);
}