import { Box, Paper, Link, useMediaQuery } from '@material-ui/core';
import React, { useEffect, useState } from 'react';
import ContentAccessor,{makeThumbnailUrl, QueryListOption, Content} from '../accessor/contents';
import {useTheme, makeStyles, Theme} from '@material-ui/core/styles';
import {Link as RouterLink} from 'react-router-dom';
import {makeContentInfoUrl} from './contentinfo';
import { LoadingCircle } from '../component/loading';
import {ThumbnailContainer} from './reader/reader';
import {TagChip} from '../component/tagchip';

const useStyles = makeStyles((theme:Theme)=>({
    root:{
        display:"grid",
        gridGap: theme.spacing(4),
    },
    anchor_thumbnail:{
        background: '#272733',
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center',
        [theme.breakpoints.up("sm")]:{
            width: theme.spacing(25),
            height: theme.spacing(25),
        }
    },
    contentPaper:{
        display:'flex',
        flexDirection: 'column',
        [theme.breakpoints.up("sm")]:{
            height:200,
            flexDirection: 'row',
        },
    },
    content_thumnail: {
        maxWidth: '100%',
        maxHeight: '100%',
    },
    content_info:{
        padding: `${theme.spacing(1)}px ${theme.spacing(2)}px`,
        width: '100%',
        display: 'flex',
        flexDirection: 'column',
    },
    content_info_title:{
        marginLeft:theme.spacing(2),
    },
    tag_list:{
        display:'none',
        [theme.breakpoints.up("sm")]:{
            display: 'flex',
            justifyContent: 'flex-start',
            flexWrap: 'wrap',
            overflowY: 'hidden',
            '& > *': {
                margin: theme.spacing(0.5),
            },
        },
    },
}));

export type GalleryProp = {
    option?:QueryListOption;
};
type GalleryState = {
    content:Content[]|undefined;
}

export const Gallery = (props: GalleryProp)=>{
    const [state,setState]= useState<GalleryState>({content:undefined});
    useEffect(()=>{
        (async ()=>{
            const c = await ContentAccessor.findList(props.option);
            setState({content:c});
        })()
    },[props.option]);
    const num = 1;
    const classes = useStyles();
    const theme = useTheme();
    const isMobile = !useMediaQuery(theme.breakpoints.up("sm"));
        if(state.content === undefined){
            return (<LoadingCircle/>);
        }
        else{
            return (<div className={classes.root}>{
                state.content.map(x=>{
                    const thumbnail_url = makeThumbnailUrl(x);
                    return (<Paper key={x.id} elevation={4} className={classes.contentPaper}>
                        <Link className={classes.anchor_thumbnail}
                             component={RouterLink} to={makeContentInfoUrl(x.id)}>
                            <ThumbnailContainer content={x} className={classes.content_thumnail}></ThumbnailContainer>
                        </Link>
                        <Box className={classes.content_info}>
                            <Link component={RouterLink} to={makeContentInfoUrl(x.id)} variant="h5" color="inherit"
                                className={classes.content_info_title}>
                                {x.title}
                            </Link>
                            <Box className={classes.tag_list}>
                                {x.tags.map(x=>{
                                    return (<TagChip key={x} label={x} clickable={true} tagname={x} size="small"></TagChip>);
                            })}
                            </Box>
                        </Box>
                    </Paper>);
                })
                }
                </div>);
        }
}